]> git.lyx.org Git - lyx.git/blobdiff - src/Row.h
Fix bug #7404.
[lyx.git] / src / Row.h
index 7ae9c11b1e3850adc16ccaddf129edd7b382e5cd..49513d32b970b63124ce6a3c5290283ab145b317 100644 (file)
--- a/src/Row.h
+++ b/src/Row.h
@@ -136,12 +136,33 @@ public:
 
        ///
        Row();
+       /**
+        * Helper function: set variable \c var to value \c val, and mark
+        * row as changed is the values were different. This is intended
+        * for use when changing members of the row object.
+        */
+       template<class T1, class T2>
+       void change(T1 & var, T2 const val) {
+               if (var != val)
+                       changed(true);
+               var = val;
+       }
+       /**
+        * Helper function: set variable \c var to value \c val, and mark
+        * row as changed is the values were different. This is intended
+        * for use when changing members of the row object.
+        * This is the const version, useful for mutable members.
+        */
+       template<class T1, class T2>
+       void change(T1 & var, T2 const val) const {
+               if (var != val)
+                       changed(true);
+               var = val;
+       }
        ///
        bool changed() const { return changed_; }
        ///
-       void setChanged(bool c) { changed_ = c; }
-       ///
-       void setCrc(size_type crc) const;
+       void changed(bool c) const { changed_ = c; }
        /// Set the selection begin and end.
        /**
          * This is const because we update the selection status only at draw()
@@ -171,6 +192,10 @@ public:
        void right_boundary(bool b) { right_boundary_ = b; }
        ///
        bool right_boundary() const { return right_boundary_; }
+       ///
+       void flushed(bool b) { flushed_ = b; }
+       ///
+       bool flushed() const { return flushed_; }
 
        ///
        Dimension const & dimension() const { return dim_; }
@@ -243,10 +268,11 @@ public:
         * separator and update endpos if necessary. If all that
         * remains is a large word, cut it to \param width.
         * \param body_pos minimum amount of text to keep.
* \param width maximum width of the row
         * \return true if the row has been shortened.
         */
-       bool shortenIfNeeded(pos_type const body_pos, int const width);
+       bool shortenIfNeeded(pos_type const body_pos, int const width, int const next_width);
 
        /**
         * If last element of the row is a string, compute its width
@@ -259,6 +285,15 @@ public:
         * This should be called once the row is completely built.
         */
        void reverseRTL(bool rtl_par);
+       ///
+       bool isRTL() const { return rtl_; }
+       ///
+       bool needsChangeBar() const { return changebar_; }
+       ///
+       void needsChangeBar(bool ncb) { changebar_ = ncb; }
+
+       /// Find row element that contains \c pos, and compute x offset.
+       const_iterator const findElement(pos_type pos, bool boundary, double & x) const;
 
        friend std::ostream & operator<<(std::ostream & os, Row const & row);
 
@@ -301,18 +336,22 @@ private:
 
        /// has the Row appearance changed since last drawing?
        mutable bool changed_;
-       /// CRC of row contents.
-       mutable size_type crc_;
        /// Index of the paragraph that contains this row
        pit_type pit_;
        /// first pos covered by this row
        pos_type pos_;
        /// one behind last pos covered by this row
        pos_type end_;
-       // Is there is a boundary at the end of the row (display inset...)
+       // Is there a boundary at the end of the row (display inset...)
        bool right_boundary_;
+       // Shall the row be flushed when it is supposed to be justified?
+       bool flushed_;
        /// Row dimension.
        Dimension dim_;
+       /// true when this row lives in a right-to-left paragraph
+       bool rtl_;
+       /// true when a changebar should be drawn in the margin
+       bool changebar_;
 };
@@ -243,10 +268,11 @@ public:
         * remains is a large word, cut it to \param width.
         * \param body_pos minimum amount of text to keep.
-        * \param width maximum width of the row
+        * \param width maximum width of the row.
+        * \param available width on next row.
         * \return true if the row has been shortened.
         */